#!/bin/bash
LOG_FILE="/var/log/network_monitor.log"

dbg()
{
    echo "[`date "+%H:%M:%S"`][${FUNCNAME[1]}] $@ " >> $LOG_FILE
}

start_monitor()
{
    while [ 1 ]; do
        sleep 30
        carrier=`cat /sys/class/net/eno1/carrier 2>/dev/null`
        operstate=`cat /sys/class/net/eno1/operstate 2>/dev/null`
        ip=`ip addr show eno1 | grep 'inet ' | awk '{printf $2}'`

        if [[ "${carrier}" == "1" ]] && [[ "${operstate}" == "up" ]] && [[ "${ip}" == "" ]]; then
            dbg "NO ip: ifconfig down and up"
            ifconfig eno1 down
            ifconfig eno1 up
        fi
    done
}

start_local_monitor()
{
    while [ 1 ]; do
        sleep 6
        carrier=`cat /sys/class/net/eno1/carrier 2>/dev/null`
        operstate=`cat /sys/class/net/eno1/operstate 2>/dev/null`
        linklocal=`grep link-local /etc/netplan/01-network-manager-all.yaml 2>/dev/null | wc -l`

        if [[ "${carrier}" == "1" ]] && [[ "${operstate}" == "up" ]] && [[ "${linklocal}" == "1" ]]; then
            dbg "Peek dhcp"
            touch /tmp/.tmp1_dhclient.lease
            /sbin/dhclient -e LEASEPATH=/tmp/.tmp1_dhclient.lease -sf /sbin/dhclient-script-not-configure -cf /etc/dhcp/dhclient_timeout5.conf -lf /dev/null -pf /tmp/tmp_eno1.pid eno1
            /sbin/dhclient -4 -x -sf /sbin/dhclient-script-not-configure -cf /etc/dhcp/dhclient_timeout5.conf -lf /dev/null -pf /tmp/tmp_eno1.pid
            DHCP_IP=`getcfg -f /tmp/.tmp1_dhclient.lease eno1 IP`
            rm /tmp/.tmp_dhclient.lease
            if [ $DHCP_IP != ""  ]; then
                dbg "DHCP_IP: $DHCP_IP, ifconfig down and up"
                ifconfig eno1 down
                ifconfig eno1 up
            fi
        fi
    done
}

stop_monitor()
{
    what=`basename $1`
    killall ${what} > /dev/null 2>&1
}

case "$1" in
    start)
        dbg "start"
        start_monitor
        ;;
    start_local)
        dbg "start_local"
        start_local_monitor
        ;;
    stop)
        dbg "stop"
        stop_monitor $0
        ;;
    *)
        exit 0
esac
